@@ -65,6 +65,8 @@ def main(card_db_dir, output_dir):
 
     # Get the card data
     type_data = get_json_data(os.path.join(card_db_dir, "types_db.json"))
+    types = set(tuple(t["card_type"]) for t in type_data)
+    assert len(type_data) == len(types), f"{len(type_data)} != {len(types)}"
 
     # Sort the cards by cardset_tags, then card_tag
     sorted_type_data = multikeysort(type_data, ["card_type"])
@@ -87,6 +89,7 @@ def main(card_db_dir, output_dir):
     label_data = get_json_data(os.path.join(card_db_dir, "labels_db.json"))
 
     all_labels = list(set().union(*[set(label["names"]) for label in label_data]))
+
     write_data(label_data, os.path.join(output_dir, "labels_db.json"))
 
     all_labels.sort()
@@ -123,6 +126,11 @@ def main(card_db_dir, output_dir):
             lang_type_default = lang_type_data  # Keep for later languages
 
     sorted_card_data = load_card_data(card_db_dir)
+    seen = set()
+    for c in sorted_card_data:
+        if c["card_tag"] in seen:
+            assert False, f"Duplicate card detected: {c['card_tag']}"
+        seen.add(c["card_tag"])
     groups = set(card["group_tag"] for card in sorted_card_data if "group_tag" in card)
     super_groups = set(["events", "landmarks", "projects"])
 
